<?php
//PageRank Lookup v1.1 by HM2K (update: 31/01/07)
//based on an alogoritham found here: http://pagerank.gamesaga.net/

//settings - host and user agent
$googlehost='toolbarqueries.google.com';
$googleua='Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.6) Gecko/20060728 Firefox/1.5';

//convert a string to a 32-bit integer
function StrToNum($Str, $Check, $Magic) {
    $Int32Unit = 4294967296;  // 2^32

    $length = strlen($Str);
    for ($i = 0; $i < $length; $i++) {
        $Check *= $Magic; 	
        //If the float is beyond the boundaries of integer (usually +/- 2.15e+9 = 2^31), 
        //  the result of converting to integer is undefined
        //  refer to http://www.php.net/manual/en/language.types.integer.php
        if ($Check >= $Int32Unit) {
            $Check = ($Check - $Int32Unit * (int) ($Check / $Int32Unit));
            //if the check less than -2^31
            $Check = ($Check < -2147483648) ? ($Check + $Int32Unit) : $Check;
        }
        $Check += ord($Str{$i}); 
    }
    return $Check;
}

//genearate a hash for a url
function HashURL($String) {
    $Check1 = StrToNum($String, 0x1505, 0x21);
    $Check2 = StrToNum($String, 0, 0x1003F);

    $Check1 >>= 2; 	
    $Check1 = (($Check1 >> 4) & 0x3FFFFC0 ) | ($Check1 & 0x3F);
    $Check1 = (($Check1 >> 4) & 0x3FFC00 ) | ($Check1 & 0x3FF);
    $Check1 = (($Check1 >> 4) & 0x3C000 ) | ($Check1 & 0x3FFF);	
	
    $T1 = (((($Check1 & 0x3C0) << 4) | ($Check1 & 0x3C)) <<2 ) | ($Check2 & 0xF0F );
    $T2 = (((($Check1 & 0xFFFFC000) << 4) | ($Check1 & 0x3C00)) << 0xA) | ($Check2 & 0xF0F0000 );
	
    return ($T1 | $T2);
}

//genearate a checksum for the hash string
function CheckHash($Hashnum) {
    $CheckByte = 0;
    $Flag = 0;

    $HashStr = sprintf('%u', $Hashnum) ;
    $length = strlen($HashStr);
	
    for ($i = $length - 1;  $i >= 0;  $i --) {
        $Re = $HashStr{$i};
        if (1 === ($Flag % 2)) {              
            $Re += $Re;     
            $Re = (int)($Re / 10) + ($Re % 10);
        }
        $CheckByte += $Re;
        $Flag ++;	
    }

    $CheckByte %= 10;
    if (0 !== $CheckByte) {
        $CheckByte = 10 - $CheckByte;
        if (1 === ($Flag % 2) ) {
            if (1 === ($CheckByte % 2)) {
                $CheckByte += 9;
            }
            $CheckByte >>= 1;
        }
    }

    return '7'.$CheckByte.$HashStr;
}

//return the pagerank checksum hash
function getch($url) { return CheckHash(HashURL($url)); }

//return the pagerank figure
function getpr($url) {
	global $googlehost,$googleua;
	$ch = getch($url);
	$fp = fsockopen($googlehost, 80, $errno, $errstr, 30);
	if ($fp) {
	   $out = "GET /search?client=navclient-auto&ch=$ch&features=Rank&q=info:$url HTTP/1.1\r\n";
	   //echo "<pre>$out</pre>\n"; //debug only
	   $out .= "User-Agent: $googleua\r\n";
	   $out .= "Host: $googlehost\r\n";
	   $out .= "Connection: Close\r\n\r\n";
	
	   fwrite($fp, $out);
	   
	   //$pagerank = substr(fgets($fp, 128), 4); //debug only
	   //echo $pagerank; //debug only
	   while (!feof($fp)) {
			$data = fgets($fp, 128);
			//echo $data;
			$pos = strpos($data, "Rank_");
			if($pos === false){} else{
				$pr=substr($data, $pos + 9);
				$pr=trim($pr);
				$pr=str_replace("\n",'',$pr);
				return $pr;
			}
	   }
	   //else { echo "$errstr ($errno)<br />\n"; } //debug only
	   fclose($fp);
	}
}

//generate the graphical pagerank
function pagerank($url,$width=54,$method='style') {
	if (!preg_match('/^(http:\/\/)?([^\/]+)/i', $url)) { $url='http://'.$url; }
	$pr=getpr($url);
	$pagerank="PageRank: $pr/10";

	//The (old) image method
	if ($method == 'image') {
	$prpos=$width*$pr/10;
	$prneg=$width-$prpos;
	$html='<div style="width='.$prpos.' height;4px; alt="<img src="http://www.google.com/images/neg.gif" width='.$prneg.' height=4 border=0 alt="'.$pagerank.'">';
	}
	//The pre-styled method
	if ($method == 'style') {
	$prpercent=100*$pr/10;
    if($pr == ''){
        $pagerank = 'N';
    }else{
        $pagerank = $pr;
    }
	$html= '
    <div style="line-height:normal;padding-left:4px;padding-right:2px;float:left;width:82px;height:24px;border:1px solid #cacaca;background-color:#f9f9f9;">
    <span style="float:left;width:56px;text-align:center;color:#989898;font-family:tahoma;font-size:10px;margin-top:1px;">Page Rank</span>
    <div style="float:right;width:20px;height:18px;background-color:#fff;border:1px solid #cacaca;color:#5e7e22;font-size:14px;font-family:tahoma;text-align:center;font-weight:bold;margin-top:2px;">
    '.$pagerank.'
    </div>
    <div style="margin-top:3px;float:left;position: relative; width: '.$width.'px; border:1px solid #abc776; padding:0px; background:#fff;height:4px;">
    <strong style="float:left;width: '.$prpercent.'%; display: block; position: relative; background: #abc776; text-align: center; color: #333; height: 4px;overflow:hidden; line-height: 4px;">
    </strong>
    </div>
    </div>';
	}
	
	$out= $html;
	return $out;
}

function alexa($url){
    $xml = simplexml_load_file("http://data.alexa.com/data?cli=10&dat=s&url=".$url);
    $result = $xml->xpath("//POPULARITY[@TEXT]");
    $new = $result[0];
    if(!$result){
        $numb = 'N'; 
    }else{ 
        $numb = number_format($new->attributes()->TEXT);
    }                                                                                                                                  
    $html =
    '<div id="alexa" style="float:left;line-height:normal;clear:left;padding-left:4px;padding-right:2px;width:160px;height:24px;border:1px solid #cacaca;background-color:#f9f9f9;">
<span style="padding-right:4px;float:left;width:56px;text-align:center;color:#989898;font-family:tahoma;font-size:11px;margin-top:6px;">Alexa Rank</span>
<div style="float:right;padding-left:3px;padding-right:3px;;height:18px;background-color:#fff;border:1px solid #cacaca;color:#5e7e22;font-size:14px;font-family:tahoma;text-align:center;font-weight:bold;margin-top:2px;">
'.$numb.'
</div>
</div>';
$out= $html; 
return $out;
}

function domaintoip($url){
$x = gethostbyname($url);
return $x;
}

function googleindex($url,$api_key){
$urls = urlencode($url);
$search = 'site:\+'.$urls;
     $content = file_get_contents('http://ajax.googleapis.com/ajax/services/search/web?v=1.0&key='.$api_key.'&q='.$search);
         $data = json_decode($content);
         $googleindex = intval($data->responseData->cursor->estimatedResultCount);
 return $googleindex;
}

function backlinks($url,$api_key){
$urls = urlencode($url);
$search = '"'.$urls.'"\+\link:'.$urls;
     $content = file_get_contents('http://ajax.googleapis.com/ajax/services/search/web?v=1.0&key='.$api_key.'&q='.$search);
         $data = json_decode($content);
         $backlink = intval($data->responseData->cursor->estimatedResultCount);
 return $backlink;
}
 
 
function map($url,$api_key){
$qip = gethostbyname($url);
$qhostip= simplexml_load_file("http://ipinfodb.com/ip_query.php?ip=".$qip);
$result = $qhostip->xpath("//*");
$new = $result[10].','; 
$new .= $result[9];

$html="<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n";
$html.="<html xmlns=\"http://www.w3.org/1999/xhtml\">\n";
$html.="<head>\n";
$html.="<title>Google Maps IP</title>\n";
$html.="<script src=\"http://maps.google.com/maps?file=api&v=1&key=".$api_key."\" type=\"text/javascript\"></script>\n";
$html.="</head>\n";
$html.="<body>\n";
$html.="<div id=\"map\" style=\"width: 326px; height: 229px\"></div>\n";
$html.="<script type=\"text/javascript\">\n";
$html.="//<![CDATA[\n";
$html.="if (GBrowserIsCompatible()) {\n";
$html.="var map = new GMap(document.getElementById(\"map\"));\n";
$html.="var point = new GPoint(".$new.");\n";
$html.="map.addControl(new GSmallMapControl());\n";
$html.="map.addControl(new GMapTypeControl());";
$html.="map.centerAndZoom(point, 4);\n";
$html.="var marker = new GMarker(point);\n";
$html.="map.addOverlay(marker);\n";
$html.="}\n";
$html.="//]]>\n";
$html.="</script>\n";
$html.="</body>\n";
$html.="</html>\n";
return $html;
}

function price($url,$api_key){
    @include('config/config.php');
    @include('../config/config.php'); 
   
   preg_match_all('/<div style=".*?">(.*?)<div style=".*?">(.*?)<\/div>/s',alexa($url),$alexas,PREG_SET_ORDER);
   foreach($alexas as $alexa){
       $alex = $alexa[2];
   }
   preg_match_all('/<div style=".*?">(.*?)<div style=".*?">(.*?)<\/div>/s',pagerank($url),$pageranks,PREG_SET_ORDER);
   foreach($pageranks as $pagerank){
      $pr = $pagerank[2];
   }
   //echo backlinks($url).'<br>';
   //echo googleindex($url).'<br>';
   if($pr <= 1){
       $p1 = 100*2;
   }
   if($pr == 'N'){
       $p1 = 100*2;
   }
   if($pr == 2){
       $p1 = 200*2;   
   }
   if($pr == 3){
       $p1 = 300*2;
   }
   if($pr == 4){
       $p1 = 400*2;
   }
   if($pr == 5){
       $p1 = 500*2;
   }
   if($pr == 6){
       $p1 = 600*2;
   }
   if($pr == 7){
       $p1 = 700*2;
   }
   if($pr == 8){
       $p1 = 800*2;
   }
   if($pr == 9){
       $p1 = 900*2;
   }
   if($pr == 10){
       $p1 = 1000*2;
   }
   
   if($alex <= 0){
       $al = '2000000';
   }else{
       $al = $alex;
   }
   if(backlinks($url,$api_key) == '0'){
       $back = '1';
   }else{
       $back = backlinks($url,$api_key);
   }
   $p2 = 2000000/$al/$p1*5;
   $p3 = backlinks($url,$api_key) * $back;
   $p4 = googleindex($url,$api_key)/$back;
   $p5 = $p1 + $p2 + $p3 + $p4;
   $price = number_format($p5/1.5-133);
   	$return = $price;
   $html = '        <div style="float:left">
        <div style="float:left;background-image:url('.$site.'images/money_sign.gif);width:20px;height:34px;font-size:12px;line-height:normal;"></div>
            <div style="float:left;height:32px;border-top:1px solid #d0d0d0;border-right:1px solid #d0d0d0;border-bottom:1px solid #d0d0d0;width: 115px;background-color:#f9f9f9;">
                <span style="font-size:11px; color:#989898; font-family:Tahoma, Geneva, sans-serif; width:115px;float:left;text-align:center;line-height:normal;padding:0px;margin:0px;margin-top:1px;">Website Value:</span>
                <span style="font-size:11px; font-family:Tahoma, Geneva, sans-serif; width:115px;float:left;text-align:center;line-height:normal;padding:0px;margin:0px;margin-top:1px;color:#96b55c;">'.$return.'</span>
            </div>
        </div>';
   return $html;
}

function priceall($url,$api_key){
   
   preg_match_all('/<div style=".*?">(.*?)<div style=".*?">(.*?)<\/div>/s',alexa($url),$alexas,PREG_SET_ORDER);
   foreach($alexas as $alexa){
       $alex = $alexa[2];
   }
   preg_match_all('/<div style=".*?">(.*?)<div style=".*?">(.*?)<\/div>/s',pagerank($url),$pageranks,PREG_SET_ORDER);
   foreach($pageranks as $pagerank){
      $pr = $pagerank[2];
   }
   //echo backlinks($url).'<br>';
   //echo googleindex($url).'<br>';
   if($pr <= 1){
       $p1 = 100*2;
   }
   if($pr == 'N'){
       $p1 = 100*2;
   }
   if($pr == 2){
       $p1 = 200*2;   
   }
   if($pr == 3){
       $p1 = 300*2;
   }
   if($pr == 4){
       $p1 = 400*2;
   }
   if($pr == 5){
       $p1 = 500*2;
   }
   if($pr == 6){
       $p1 = 600*2;
   }
   if($pr == 7){
       $p1 = 700*2;
   }
   if($pr == 8){
       $p1 = 800*2;
   }
   if($pr == 9){
       $p1 = 900*2;
   }
   if($pr == 10){
       $p1 = 1000*2;
   }
   
   if($alex <= 0){
       $al = '2000000';
   }else{
       $al = $alex;
   }
   if(backlinks($url,$api_key) == '0'){
       $back = '1';
   }else{
       $back = backlinks($url,$api_key);
   }
   $p2 = 2000000/$al/$p1*5;
   $p3 = backlinks($url,$api_key) * $back;
   $p4 = googleindex($url,$api_key)/$back;
   $p5 = $p1 + $p2 + $p3 + $p4;
   $price = number_format($p5/1.5-133);
   $return = $price;
   return $return;
}
?>
<?
if($_GET['type'] == 'alexa'){
    $url = $_GET['url'];
    echo alexa($url);
}

if($_GET['type'] == 'pr'){
    $url = $_GET['url'];
    echo pagerank($url);
}

if($_GET['type'] == 'price'){
    $url = $_GET['url'];
    include('../config/config.php');
    echo price($url,$api_key);
}
?>